@@ -114,6 +114,7 @@ sub setTsTranslations($$%)
 				$translation =~ s/&/&amp;/g;
 				$translation =~ s/</&lt;/g;
 				$translation =~ s/>/&gt;/g;
+				$translation =~ s/\\"/&quot;/g;
 				$translation =~ s/\\n/\n/g;
 				s/ type="unfinished"//;
 				s/<\/translation>/$translation<\/translation>/;
@@ -130,7 +131,8 @@ sub setTsTranslations($$%)
 # Generate .ts files from .po files.
 sub generateTs()
 {
-	my @languages = ("de", "es", "fr", "ru", "it", "pl", "nl");
+	my @pofiles = glob "$topdir/po/*.po";
+	my @languages = map { /^.*\W(\w+)\.po$/ } @pofiles;
 	my $tmpdir = ".tsdir";
 	mkdir $tmpdir unless -d $tmpdir;
 	mkdir "po" unless -d "po";
@@ -140,8 +142,7 @@ sub generateTs()
 	system "$lupdate_cmd " . join ' ', glob "*.cpp" . " -ts ". join ' ', map { "kid3_". $_ . ".ts" } @languages;
 	foreach my $lang (@languages) { 
 		setTsTranslations("kid3_$lang.ts", "../po/kid3_$lang.ts",
-											(getPoTranslations("$topdir/po/$lang.po"),
-											 getPoTranslations("$topdir/kid3/${lang}_qt.po")));
+											getPoTranslations("$topdir/po/$lang.po"));
 	}
 	unlink <*>;
 	chdir "..";
@@ -156,6 +157,7 @@ my $have_id3lib = 1;
 my $have_taglib = 1;
 my $taglib_includes = "-I/usr/include/taglib";
 my $have_mp4v2 = 1;
+my $have_mp4v2_mp4v2_h = 1;
 my $have_qtdbus = 0;
 my $have_tunepimp = 5;
 my $qmake_cmd = "qmake";
@@ -192,6 +194,7 @@ while (my $opt = shift) {
 		$taglib_includes = substr($opt, 23);
   } elsif ($opt eq "--without-mp4v2") {
 		$have_mp4v2 = 0;
+		$have_mp4v2_mp4v2_h = 0;
   } elsif ($opt eq "--with-dbus") {
 		$have_qtdbus = 1;
 	} elsif ($opt eq "--without-musicbrainz") {
@@ -294,6 +297,7 @@ if ($from_configure) {
 	$have_flac = 0;
 	$have_taglib = 0;
 	$have_mp4v2 = 0;
+	$have_mp4v2_mp4v2_h = 0;
 	$have_qtdbus = 0;
 	$have_tunepimp = 0;
 	$qmake_cmd = "";
@@ -325,6 +329,8 @@ if ($from_configure) {
 				$have_taglib = $1;
 			} elsif (/^#define HAVE_MP4V2 (\d+)$/) {
 				$have_mp4v2 = $1;
+			} elsif (/^#define HAVE_MP4V2_MP4V2_H (\d+)$/) {
+				$have_mp4v2_mp4v2_h = $1;
 			} elsif (/^#define HAVE_QTDBUS (\d+)$/) {
 				$have_qtdbus = $1;
 			} elsif (/^#define HAVE_TUNEPIMP (\d+)$/) {
@@ -343,7 +349,7 @@ if ($from_configure) {
 	}
 }
 
-my $config_h = "#define VERSION \"1.2\"\n";
+my $config_h = "#define VERSION \"1.3\"\n";
 my $config_pri;
 if ($prefix) {
 	$config_h .= "#define CFG_PREFIX \"$prefix\"\n";
@@ -436,6 +442,9 @@ if ($have_mp4v2) {
 	$config_h .= "#define HAVE_MP4V2 $have_mp4v2\n";
 	$config_pri .= "-lmp4v2 ";
 	$config_pri .= "-lwsock32 " if $^O eq "MSWin32" or $^O eq "msys";
+	if ($have_mp4v2_mp4v2_h) {
+		$config_h .= "#define HAVE_MP4V2_MP4V2_H $have_mp4v2_mp4v2_h\n";
+	}
 }
 if ($have_tunepimp) {
 	$config_h .= "#define HAVE_TUNEPIMP $have_tunepimp\n";
@@ -563,9 +572,10 @@ if (open IF, "$topdir/kid3/kid3.desktop") {
 	open OF, ">$fn" or die "Cannot open $fn: $!\n";
 	while (<IF>) {
 		s/^Name=Kid3$/Name=Kid3-qt/;
-		s/^Exec=kid3.*$/Exec=kid3-qt/;
+		s/^Exec=kid3/Exec=kid3-qt/;
 		s/^Icon=kid3$/Icon=kid3-qt/;
-		print OF $_;
+		s/^Categories=Qt;KDE/Categories=Qt/;
+		print OF $_ unless /^X-DocPath/;
 	}
 	print "creating $fn\n";
 	close OF;
