@@ -131,6 +131,8 @@ protected slots:
 private:
 	/** Preserve timestamp checkbox */
 	QCheckBox* m_preserveTimeCheckBox;
+	/** Mark changes checkbox */
+	QCheckBox* m_markChangesCheckBox;
 	/** Mark truncated fields checkbox */
 	QCheckBox* m_markTruncationsCheckBox;
 	/** ID3v1 text encodings */
@@ -141,8 +143,12 @@ private:
 	QCheckBox* m_totalNumTracksCheckBox;
 	/** Comment field name combo box */
 	QComboBox* m_commentNameComboBox;
+#if defined HAVE_ID3LIB || defined HAVE_TAGLIB
+	/** Genre as text instead of numeric string checkbox */
+	QCheckBox* m_genreNotNumericCheckBox;
 	/** ID3v2 text encoding combo box */
 	QComboBox* m_textEncodingComboBox;
+#endif
 #if defined HAVE_ID3LIB && defined HAVE_TAGLIB
 	/** ID3v2 version combo box */
 	QComboBox* m_id3v2VersionComboBox;
@@ -163,6 +169,14 @@ private:
 	QCheckBox* m_proxyCheckBox;
 	/** Proxy line edit */
 	QLineEdit* m_proxyLineEdit;
+#if QT_VERSION >= 0x040000
+	/** Use proxy authentication check box */
+	QCheckBox* m_proxyAuthenticationCheckBox;
+	/** Proxy user name line edit */
+	QLineEdit* m_proxyUserNameLineEdit;
+	/** Proxy password line edit */
+	QLineEdit* m_proxyPasswordLineEdit;
+#endif
 #ifndef CONFIG_USE_KDE
 	QCheckBox* m_useApplicationFontCheckBox;
 	QPushButton* m_applicationFontButton;
