@@ -92,6 +92,8 @@
 #include "filterdialog.h"
 #include "rendirdialog.h"
 #include "downloaddialog.h"
+#include "playlistdialog.h"
+#include "playlistcreator.h"
 #include "filelistitem.h"
 #include "dirlist.h"
 #include "pictureframe.h"
@@ -116,115 +118,11 @@
 #endif
 
 #ifndef CONFIG_USE_KDE
-#include <qdialog.h>
-#include <qtextbrowser.h>
-#include <qlocale.h>
-
-/**
- * Help browser.
- */
-class BrowserDialog : public QDialog {
-public:
-	/**
-	 * Constructor.
-	 */
-	BrowserDialog(QWidget* parent, QString& caption);
-
-	/**
-	 * Destructor.
-	 */
-	~BrowserDialog();
-
-	/**
-	 * Show context help.
-	 * @param anchor name of anchor
-	 */
-	void goToAnchor(const QString& anchor);
-
-private:
-	QTextBrowser* m_textBrowser;
-	QString m_filename;
-};
-
-BrowserDialog::BrowserDialog(QWidget* parent, QString& caption)
-	: QDialog(parent)
-{
-	QCM_setWindowTitle(caption);
-	QVBoxLayout* vlayout = new QVBoxLayout(this);
-	if (!vlayout) {
-		return ;
-	}
-	vlayout->setSpacing(6);
-	vlayout->setMargin(6);
-
-	QString lang(QLocale::system().name().left(2));
-	QStringList docPaths;
-#ifdef CFG_DOCDIR
-	docPaths += QString(CFG_DOCDIR) + "/kid3_" + lang + ".html";
-	docPaths += QString(CFG_DOCDIR) + "/kid3_en.html";
-#endif
-	docPaths += QDir::QCM_currentPath() + "/kid3_" + lang + ".html";
-	docPaths += QDir::QCM_currentPath() + "/kid3_en.html";
-	for (QStringList::const_iterator it = docPaths.begin();
-			 it != docPaths.end();
-			 ++it) {
-		m_filename = *it;
-		if (QFile::exists(m_filename)) break;
-	}
-	m_textBrowser = new QTextBrowser(this);
-#if QT_VERSION >= 0x040000
-	m_textBrowser->setSource(QUrl::fromLocalFile(m_filename));
-#else
-	m_textBrowser->setSource(m_filename);
-#endif
-	vlayout->addWidget(m_textBrowser);
-
-	QHBoxLayout* hlayout = new QHBoxLayout;
-	QSpacerItem* hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
-	                                       QSizePolicy::Minimum);
-	QPushButton* backButton = new QPushButton(i18n("&Back"), this);
-	QPushButton* forwardButton = new QPushButton(i18n("&Forward"), this);
-	QPushButton* closeButton = new QPushButton(i18n("&Close"), this);
-	if (hlayout && backButton && forwardButton && closeButton) {
-		hlayout->addWidget(backButton);
-		hlayout->addWidget(forwardButton);
-		hlayout->addItem(hspacer);
-		hlayout->addWidget(closeButton);
-		closeButton->setDefault(true);
-		backButton->setEnabled(false);
-		forwardButton->setEnabled(false);
-		connect(backButton, SIGNAL(clicked()), m_textBrowser, SLOT(backward()));
-		connect(forwardButton, SIGNAL(clicked()), m_textBrowser, SLOT(forward()));
-		connect(m_textBrowser, SIGNAL(backwardAvailable(bool)), backButton, SLOT(setEnabled(bool)));
-		connect(m_textBrowser, SIGNAL(forwardAvailable(bool)), forwardButton, SLOT(setEnabled(bool)));
-		connect(closeButton, SIGNAL(clicked()), this, SLOT(accept()));
-		vlayout->addLayout(hlayout);
-	}
-	resize(500, 500);
-}
-
-BrowserDialog::~BrowserDialog()
-{}
-
-void BrowserDialog::goToAnchor(const QString& anchor)
-{
-#if QT_VERSION >= 0x040000
-	QUrl url = QUrl::fromLocalFile(m_filename);
-	url.setFragment(anchor);
-	m_textBrowser->setSource(url);
-#else
-	if (!anchor.isEmpty()) {
-		m_textBrowser->setSource(m_filename + '#' + anchor);
-	} else {
-		m_textBrowser->setSource(m_filename);
-	}
-#endif
-}
+#include "browserdialog.h"
 
 BrowserDialog* Kid3App::s_helpBrowser = 0;
 #endif
 
-
 MiscConfig Kid3App::s_miscCfg("General Options");
 ImportConfig Kid3App::s_genCfg("General Options");
 FormatConfig Kid3App::s_fnFormatCfg("FilenameFormat");
@@ -234,6 +132,7 @@ FreedbConfig Kid3App::s_trackTypeCfg("TrackType");
 DiscogsConfig Kid3App::s_discogsCfg("Discogs");
 MusicBrainzConfig Kid3App::s_musicBrainzCfg("MusicBrainz");
 FilterConfig Kid3App::s_filterCfg("Filter");
+PlaylistConfig Kid3App::s_playlistCfg("Playlist");
 
 /** Current directory */
 QString Kid3App::s_dirName;
@@ -245,7 +144,8 @@ Kid3App::Kid3App() :
 	m_downloadToAllFilesInDir(false),
 	m_importDialog(0), m_browseCoverArtDialog(0),
 	m_exportDialog(0), m_renDirDialog(0),
-	m_numberTracksDialog(0), m_filterDialog(0), m_downloadDialog(0)
+	m_numberTracksDialog(0), m_filterDialog(0), m_downloadDialog(0),
+	m_playlistDialog(0)
 {
 #ifdef CONFIG_USE_KDE
 #if KDE_VERSION >= 0x035c00
@@ -317,6 +217,7 @@ Kid3App::~Kid3App()
 	delete m_filterDialog;
 	delete m_downloadDialog;
 	delete m_browseCoverArtDialog;
+	delete m_playlistDialog;
 #ifndef CONFIG_USE_KDE
 	delete s_helpBrowser;
 	s_helpBrowser = 0;
@@ -423,8 +324,8 @@ void Kid3App::initActions()
 		    SLOT(slotExport()), actionCollection(),
 		    "export");
 	KCM_KActionIcon(fileCreatePlaylist, KCM_ICON_media_playlist,
-		    i18n("&Create Playlist"), this,
-				SLOT(slotCreatePlaylist()), actionCollection(),
+		    i18n("&Create Playlist..."), this,
+				SLOT(slotPlaylistDialog()), actionCollection(),
 				"create_playlist");
 	KCM_KAction(toolsApplyFilenameFormat,
 		    i18n("Apply &Filename Format"), this,
@@ -630,9 +531,9 @@ void Kid3App::initActions()
 	QAction* fileCreatePlaylist = new QAction(this);
 	if (fileCreatePlaylist) {
 		fileCreatePlaylist->setStatusTip(i18n("Create M3U Playlist"));
-		fileCreatePlaylist->QCM_setMenuText(i18n("&Create Playlist"));
+		fileCreatePlaylist->QCM_setMenuText(i18n("&Create Playlist..."));
 		connect(fileCreatePlaylist, QCM_SIGNAL_triggered,
-			this, SLOT(slotCreatePlaylist()));
+			this, SLOT(slotPlaylistDialog()));
 	}
 	QAction* fileQuit = new QAction(this);
 	if (fileQuit) {
@@ -979,6 +880,7 @@ void Kid3App::saveOptions()
 	s_trackTypeCfg.writeToConfig(m_config);
 	s_discogsCfg.writeToConfig(m_config);
 	s_filterCfg.writeToConfig(m_config);
+	s_playlistCfg.writeToConfig(m_config);
 #ifdef HAVE_TUNEPIMP
 	s_musicBrainzCfg.writeToConfig(m_config);
 #endif
@@ -1029,6 +931,7 @@ void Kid3App::readOptions()
 	}
 	s_discogsCfg.readFromConfig(m_config);
 	s_filterCfg.readFromConfig(m_config);
+	s_playlistCfg.readFromConfig(m_config);
 #ifdef HAVE_TUNEPIMP
 	s_musicBrainzCfg.readFromConfig(m_config);
 #endif
@@ -1482,7 +1385,9 @@ void Kid3App::slotFileOpen()
 			if (start != -1 && end != -1 && end > start) {
 				filter = filter.mid(start + 1, end - start - 1);
 			}
-			s_miscCfg.m_nameFilter = filter;
+			if (!filter.isEmpty()) {
+				s_miscCfg.m_nameFilter = filter;
+			}
 			openDirectory(dir);
 		}
 	}
@@ -1744,6 +1649,87 @@ void Kid3App::slotStatusMsg(const QString& text)
 #endif
 }
 
+/**
+ * Show playlist dialog.
+ */
+void Kid3App::slotPlaylistDialog()
+{
+	if (!m_playlistDialog) {
+		m_playlistDialog = new PlaylistDialog(0);
+	}
+	if (m_playlistDialog) {
+		m_playlistDialog->readConfig();
+		if (m_playlistDialog->exec() == QDialog::Accepted) {
+			PlaylistConfig cfg;
+			m_playlistDialog->getCurrentConfig(cfg);
+			writePlaylist(cfg);
+		}
+	}
+}
+
+/**
+ * Write playlist according to playlist configuration.
+ *
+ * @param cfg playlist configuration to use
+ *
+ * @return true if ok.
+ */
+bool Kid3App::writePlaylist(const PlaylistConfig& cfg)
+{
+	PlaylistCreator plCtr(m_view->getDirInfo()->getDirname(), cfg);
+	QString selectedDirPrefix;
+	FileListItem* item = cfg.m_location == PlaylistConfig::PL_CurrentDirectory ?
+		m_view->firstFileInDir() : m_view->firstFileOrDir();
+	bool noSelection = !cfg.m_onlySelectedFiles ||
+		m_view->numFilesOrDirsSelected() == 0;
+	bool ok = true;
+	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+	slotStatusMsg(i18n("Creating playlist..."));
+	while (item != 0) {
+		PlaylistCreator::Item plItem(item, plCtr);
+		bool inSelectedDir = false;
+		if (cfg.m_location != PlaylistConfig::PL_CurrentDirectory &&
+				plItem.isDir()) {
+			if (!selectedDirPrefix.isEmpty()) {
+				if (plItem.getDirName().startsWith(selectedDirPrefix)) {
+					inSelectedDir = true;
+				} else {
+					selectedDirPrefix = "";
+				}
+			}
+			if (inSelectedDir || noSelection || item->isSelected()) {
+				// if directory is selected, all its files are selected
+#if QT_VERSION >= 0x040000
+				item->setExpanded(true);
+#else
+				item->setOpen(true);
+#endif
+				if (!inSelectedDir) {
+					selectedDirPrefix = plItem.getDirName();
+				}
+			}
+		} else if (plItem.isFile()) {
+			QString dirName = plItem.getDirName();
+			if (!selectedDirPrefix.isEmpty()) {
+				if (dirName.startsWith(selectedDirPrefix)) {
+					inSelectedDir = true;
+				} else {
+					selectedDirPrefix = "";
+				}
+			}
+			if (inSelectedDir || noSelection || item->isSelected()) {
+				ok = plItem.add() && ok;
+			}
+		}
+		item = cfg.m_location == PlaylistConfig::PL_CurrentDirectory ?
+			m_view->nextFileInDir() : m_view->nextFileOrDir();
+	}
+	ok = plCtr.write() && ok;
+	slotStatusMsg(i18n("Ready."));
+	QApplication::restoreOverrideCursor();
+	return ok;
+}
+
 /**
  * Create playlist.
  *
@@ -1751,26 +1737,7 @@ void Kid3App::slotStatusMsg(const QString& text)
  */
 bool Kid3App::slotCreatePlaylist()
 {
-	FileListItem* mp3file = m_view->firstFileInDir();
-	if (!(mp3file && mp3file->getFile())) return false;
-	QDir dir(mp3file->getFile()->getDirname());
-	QString dirname = dir.QCM_absolutePath();
-	QString fn = dirname + QDir::separator() + dir.dirName() + ".m3u";
-	QFile file(fn);
-	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-	slotStatusMsg(i18n("Creating playlist..."));
-	bool ok = file.open(QCM_WriteOnly);
-	if (ok) {
-		QTextStream stream(&file);
-		while (mp3file != 0) {
-			stream << mp3file->getFile()->getFilename() << "\n";
-			mp3file = m_view->nextFileInDir();
-		}
-		file.close();
-	}
-	slotStatusMsg(i18n("Ready."));
-	QApplication::restoreOverrideCursor();
-	return ok;
+	return writePlaylist(s_playlistCfg);
 }
 
 /**
@@ -2015,7 +1982,7 @@ void Kid3App::slotBrowseCoverArt()
  *
  * @return tagged file (can be new TagLibFile).
  */
-static TaggedFile* readWithTagLibIfId3V24(FileListItem* item,
+TaggedFile* Kid3App::readWithTagLibIfId3V24(FileListItem* item,
 																					TaggedFile* taggedFile)
 {
 	if (dynamic_cast<Mp3File*>(taggedFile) != 0 &&
@@ -2802,7 +2769,7 @@ void Kid3App::downloadImage(const QString& url, bool allFilesInDir)
 					m_downloadDialog->startDownload(
 						imgurl.mid(hostPos + 3, pathPos - hostPos - 3),
 						imgurl.mid(pathPos));
-					m_downloadDialog->exec();
+					m_downloadDialog->show();
 				}
 			}
 		}
@@ -2997,17 +2964,6 @@ void Kid3App::updateGuiControls()
 				single_v2_file->getChangedFramesV2());
 			m_view->markChangedFilename(single_v2_file->isFilenameChanged());
 		}
-
-		if (!s_miscCfg.m_hidePicture) {
-			FrameCollection::const_iterator it =
-				m_view->frameTableV2()->frames().find(Frame(Frame::FT_Picture, "", "", -1));
-			if (it == m_view->frameTableV2()->frames().end()) {
-				m_view->setPictureData(0);
-			} else {
-				QByteArray data;
-				m_view->setPictureData(PictureFrame::getData(*it, data) ? &data : 0);
-			}
-		}
 	}
 	else {
 		m_view->setFilenameEditEnabled(false);
@@ -3023,8 +2979,16 @@ void Kid3App::updateGuiControls()
 			m_view->frameTableV2()->markChangedFrames(0);
 			m_view->markChangedFilename(false);
 		}
-		if (!s_miscCfg.m_hidePicture) {
+	}
+	if (!s_miscCfg.m_hidePicture) {
+		FrameCollection::const_iterator it =
+			m_view->frameTableV2()->frames().find(Frame(Frame::FT_Picture, "", "", -1));
+		if (it == m_view->frameTableV2()->frames().end() ||
+				it->isInactive()) {
 			m_view->setPictureData(0);
+		} else {
+			QByteArray data;
+			m_view->setPictureData(PictureFrame::getData(*it, data) ? &data : 0);
 		}
 	}
 	m_view->frameTableV1()->setAllCheckBoxes(num_files_selected == 1);
