@@ -5,6 +5,23 @@
  * \b Project: Kid3
  * \author Urs Fleisch
  * \date 13 Sep 2005
+ *
+ * Copyright (C) 2005-2007  Urs Fleisch
+ *
+ * This file is part of Kid3.
+ *
+ * Kid3 is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Kid3 is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef MUSICBRAINZDIALOG_H
@@ -17,16 +34,17 @@
 #include <qstring.h>
 #include "qtcompatmac.h"
 #if QT_VERSION >= 0x040000
-#include <Q3ValueVector>
+#include <QVector>
+class QTableWidget;
 #else
 #include <qvaluevector.h>
+class QTable;
 #endif
 
 class QLineEdit;
 class QComboBox;
 class QPushButton;
 class QCheckBox;
-class Q3Table;
 class QTimer;
 class QStatusBar;
 class MusicBrainzConfig;
@@ -181,12 +199,20 @@ private:
 	void stopClient();
 
 	QComboBox* m_serverComboBox;
-	Q3Table* m_albumTable;
+#if QT_VERSION >= 0x040000
+	QTableWidget* m_albumTable;
+#else
+	QTable* m_albumTable;
+#endif
 	QStatusBar* m_statusBar;
 	QTimer* m_timer;
 	MusicBrainzClient* m_client;
 	ImportTrackDataVector& m_trackDataVector;
-	Q3ValueVector<ImportTrackDataVector> m_trackResults;
+#if QT_VERSION >= 0x040000
+	QVector<ImportTrackDataVector> m_trackResults;
+#else
+	QValueVector<ImportTrackDataVector> m_trackResults;
+#endif
 #endif // HAVE_TUNEPIMP
 };
 
