@@ -116,6 +116,17 @@ bool ScriptInterface::importFromFile(int tagMask, const QString& path, int fmtId
 	return m_app->importTags(tagMask, path, fmtIdx);
 }
 
+/**
+ * Download album cover art into the picture frame of the selected files.
+ *
+ * @param url           URL of picture file or album art resource
+ * @param allFilesInDir true to add the image to all files in the directory
+ */
+void ScriptInterface::downloadAlbumArt(const QString& url, bool allFilesInDir)
+{
+	m_app->downloadImage(url, allFilesInDir);
+}
+
 /**
  * Export tags to a file.
  *
@@ -634,6 +645,7 @@ bool ScriptInterface::save() { return false; }
 QString ScriptInterface::getErrorMessage() const { return ""; }
 void ScriptInterface::revert() {}
 bool ScriptInterface::importFromFile(int, const QString&, int) { return false; }
+void ScriptInterface::downloadAlbumArt(const QString&, bool) {}
 bool ScriptInterface::exportToFile(int, const QString&, int) { return false; }
 bool ScriptInterface::createPlaylist() { return false; }
 void ScriptInterface::quit() {}
